# coding: utf-8

"""
    paddlehelix_dev

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from paddlehelix.configuration import Configuration


class GetVoucherListRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'task_type': 'list[int]',
        'status': 'list[int]',
        'page': 'int',
        'page_size': 'int',
        'order_by': 'str',
        'order': 'str'
    }

    attribute_map = {
        'task_type': 'task_type',
        'status': 'status',
        'page': 'page',
        'page_size': 'page_size',
        'order_by': 'order_by',
        'order': 'order'
    }

    def __init__(self, task_type=None, status=None, page=None, page_size=None, order_by=None, order=None, local_vars_configuration=None):  # noqa: E501
        """GetVoucherListRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._task_type = None
        self._status = None
        self._page = None
        self._page_size = None
        self._order_by = None
        self._order = None
        self.discriminator = None

        self.task_type = task_type
        self.status = status
        self.page = page
        self.page_size = page_size
        self.order_by = order_by
        self.order = order

    @property
    def task_type(self):
        """Gets the task_type of this GetVoucherListRequest.  # noqa: E501

        适用任务类型 0代表适用全部  # noqa: E501

        :return: The task_type of this GetVoucherListRequest.  # noqa: E501
        :rtype: list[int]
        """
        return self._task_type

    @task_type.setter
    def task_type(self, task_type):
        """Sets the task_type of this GetVoucherListRequest.

        适用任务类型 0代表适用全部  # noqa: E501

        :param task_type: The task_type of this GetVoucherListRequest.  # noqa: E501
        :type: list[int]
        """
        if self.local_vars_configuration.client_side_validation and task_type is None:  # noqa: E501
            raise ValueError("Invalid value for `task_type`, must not be `None`")  # noqa: E501

        self._task_type = task_type

    @property
    def status(self):
        """Gets the status of this GetVoucherListRequest.  # noqa: E501

        状态 10:正常 1:停用 -1:删除 3:过期  # noqa: E501

        :return: The status of this GetVoucherListRequest.  # noqa: E501
        :rtype: list[int]
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GetVoucherListRequest.

        状态 10:正常 1:停用 -1:删除 3:过期  # noqa: E501

        :param status: The status of this GetVoucherListRequest.  # noqa: E501
        :type: list[int]
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def page(self):
        """Gets the page of this GetVoucherListRequest.  # noqa: E501

        页数，默认1  # noqa: E501

        :return: The page of this GetVoucherListRequest.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this GetVoucherListRequest.

        页数，默认1  # noqa: E501

        :param page: The page of this GetVoucherListRequest.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and page is None:  # noqa: E501
            raise ValueError("Invalid value for `page`, must not be `None`")  # noqa: E501

        self._page = page

    @property
    def page_size(self):
        """Gets the page_size of this GetVoucherListRequest.  # noqa: E501

        每页数量，默认10000  # noqa: E501

        :return: The page_size of this GetVoucherListRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this GetVoucherListRequest.

        每页数量，默认10000  # noqa: E501

        :param page_size: The page_size of this GetVoucherListRequest.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and page_size is None:  # noqa: E501
            raise ValueError("Invalid value for `page_size`, must not be `None`")  # noqa: E501

        self._page_size = page_size

    @property
    def order_by(self):
        """Gets the order_by of this GetVoucherListRequest.  # noqa: E501

        排序字段，支持 id, start_time, end_time, amount, rest_amount, created_at  # noqa: E501

        :return: The order_by of this GetVoucherListRequest.  # noqa: E501
        :rtype: str
        """
        return self._order_by

    @order_by.setter
    def order_by(self, order_by):
        """Sets the order_by of this GetVoucherListRequest.

        排序字段，支持 id, start_time, end_time, amount, rest_amount, created_at  # noqa: E501

        :param order_by: The order_by of this GetVoucherListRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and order_by is None:  # noqa: E501
            raise ValueError("Invalid value for `order_by`, must not be `None`")  # noqa: E501

        self._order_by = order_by

    @property
    def order(self):
        """Gets the order of this GetVoucherListRequest.  # noqa: E501

        排序方式 ASC：升序 DESC：降序  # noqa: E501

        :return: The order of this GetVoucherListRequest.  # noqa: E501
        :rtype: str
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this GetVoucherListRequest.

        排序方式 ASC：升序 DESC：降序  # noqa: E501

        :param order: The order of this GetVoucherListRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and order is None:  # noqa: E501
            raise ValueError("Invalid value for `order`, must not be `None`")  # noqa: E501

        self._order = order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetVoucherListRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetVoucherListRequest):
            return True

        return self.to_dict() != other.to_dict()
